@@ -9,27 +9,23 @@ import pkg_resources
 import dcyd.utils.constants as constants
 
 
+def get_gcp_project_id():
+    '''Returns the GCP project_id, found in the key .json file.'''
+
+    with open(os.environ[constants.DCYD_CONFIG_ENV_VAR], 'r') as f:
+        config = json.load(f)
+
+    # Use brackets, since I want to raise an error if key not found.
+    return config['project_id']
+
+
 def get_project_id():
-    '''Returns the Google Cloud project_id found in the key .json file.'''
-
+    '''Returns the MPM project_id, found in the key .json file.'''
     with open(os.environ[constants.DCYD_CONFIG_ENV_VAR], 'r') as f:
-        key = json.load(f)
+        config = json.load(f)
 
     # Use brackets, since I want to raise an error if key not found.
-    return key['project_id']
-
-
-def get_account_data():
-    '''Returns relevant Google Cloud account data found in the key .json file.'''
-    with open(os.environ[constants.DCYD_CONFIG_ENV_VAR], 'r') as f:
-        key = json.load(f)
-
-    # Use brackets, since I want to raise an error if key not found.
-    return {
-        'account_id': key['client_id'],
-        'account_email': key['client_email'],
-        'private_key_id': key['private_key_id']
-    }
+    return config['mpm_project_id']
 
 
 def get_mpm_client_data():
